# Generated by roxygen2: do not edit by hand

export("%>%")
export(predictAge)
export(predictEthnicity)
export(predictPreeclampsia)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,n)
importFrom(dplyr,row_number)
importFrom(magrittr,"%>%")
importFrom(methods,hasArg)
importFrom(methods,is)
importFrom(stats,setNames)
importFrom(tibble,tibble)
